@@ -1,4 +1,4 @@
-/*	$NetBSD: fancy.c,v 1.9 1999/02/10 17:08:06 hubertf Exp $	*/
+/*	$NetBSD: fancy.c,v 1.11 2003/08/07 09:36:57 agc Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,14 +34,14 @@
 #if 0
 static char sccsid[] = "@(#)fancy.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: fancy.c,v 1.9 1999/02/10 17:08:06 hubertf Exp $");
+__RCSID("$NetBSD: fancy.c,v 1.11 2003/08/07 09:36:57 agc Exp $");
 #endif
 #endif /* not lint */
 
 #include "back.h"
 
-char    PC;			/* padding character */
-char   *BC;			/* backspace sequence */
+extern char    PC;		/* padding character */
+extern char   *BC;		/* backspace sequence */
 char   *CD;			/* clear to end of screen sequence */
 char   *CE;			/* clear to end of line sequence */
 char   *CL;			/* clear screen sequence */
@@ -54,7 +50,7 @@ char   *HO;			/* home cursor sequence */
 char   *MC;			/* column cursor movement map */
 char   *ML;			/* row cursor movement map */
 char   *ND;			/* forward cursor sequence */
-char   *UP;			/* up cursor sequence */
+extern char   *UP;		/* up cursor sequence */
 
 int     lHO;			/* length of HO */
 int     lBC;			/* length of BC */
