@@ -1,4 +1,4 @@
-/*	$NetBSD: teach.c,v 1.10 1999/08/14 16:29:23 tron Exp $	*/
+/*	$NetBSD: teach.c,v 1.15 2004/02/08 22:23:50 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,17 +39,13 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 1993\n\
 #if 0
 static char sccsid[] = "@(#)teach.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: teach.c,v 1.10 1999/08/14 16:29:23 tron Exp $");
+__RCSID("$NetBSD: teach.c,v 1.15 2004/02/08 22:23:50 jsm Exp $");
 #endif
 #endif				/* not lint */
 
 #include "back.h"
 #include "tutor.h"
 
-#ifndef NCURSES_VERSION
-extern short ospeed;		/* tty output speed for termlib */
-#endif
-
 const char   *const helpm[] = {
 	"\nEnter a space or newline to roll, or",
 	"     b   to display the board",
@@ -162,5 +154,5 @@ leave()
 	fixtty(&old);
 	execl(EXEC, "backgammon", "-n", args[1]?args:0, 0);
 	writel("Help! Backgammon program is missing\007!!\n");
-	exit(-1);
+	exit(1);
 }
