@@ -1,4 +1,4 @@
-/*	$NetBSD: canfield.c,v 1.15 1999/09/12 09:02:20 jsm Exp $	*/
+/*	$NetBSD: canfield.c,v 1.19 2004/01/27 20:30:29 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 1993\n\
 #if 0
 static char sccsid[] = "@(#)canfield.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: canfield.c,v 1.15 1999/09/12 09:02:20 jsm Exp $");
+__RCSID("$NetBSD: canfield.c,v 1.19 2004/01/27 20:30:29 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -202,53 +198,53 @@ bool startedgame = FALSE, infullgame = FALSE;
 time_t acctstart;
 int dbfd = -1;
 
-void	askquit __P((int));
-void	cleanup __P((int)) __attribute__((__noreturn__));
-void	cleanupboard __P((void));
-void	clearabovemovebox __P((void));
-void	clearbelowmovebox __P((void));
-void	clearmsg __P((void));
-void	clearstat __P((void));
-void	destinerror __P((void));
-bool	diffcolor __P((const struct cardtype *, const struct cardtype *));
-void	dumberror __P((void));
-bool	finish __P((void));
-void	fndbase __P((struct cardtype **, int, int));
-void	getcmd __P((int, int, const char *));
-void	initall __P((void));
-void	initdeck __P((struct cardtype *[]));
-void	initgame __P((void));
-void	instruct __P((void));
-int	main __P((void));
-void	makeboard __P((void));
-void	movebox __P((void));
-void	movecard __P((void));
-void	movetofound __P((struct cardtype **, int));
-void	movetotalon __P((void));
-bool	notempty __P((const struct cardtype *));
-void	printbottombettingbox __P((void));
-void	printbottominstructions __P((void));
-void	printcard __P((int, int, const struct cardtype *));
-void	printrank __P((int, int, const struct cardtype *, bool));
-void	printtopbettingbox __P((void));
-void	printtopinstructions __P((void));
-bool	rankhigher __P((const struct cardtype *, int));
-bool	ranklower __P((const struct cardtype *, const struct cardtype *));
-void	removecard __P((int, int));
-int	samesuit __P((const struct cardtype *, int));
-void	showcards __P((void));
-void	showstat __P((void));
-void	shuffle __P((struct cardtype *[]));
-void	simpletableau __P((struct cardtype **, int));
-void	startgame __P((void));
-void	suspend __P((void));
-bool	tabok __P((const struct cardtype *, int));
-void	tabprint __P((int, int));
-void	tabtotab __P((int, int));
-void	transit __P((struct cardtype **, struct cardtype **));
-void	updatebettinginfo __P((void));
-void	usedstock __P((void));
-void	usedtalon __P((void));
+void	askquit(int);
+void	cleanup(int) __attribute__((__noreturn__));
+void	cleanupboard(void);
+void	clearabovemovebox(void);
+void	clearbelowmovebox(void);
+void	clearmsg(void);
+void	clearstat(void);
+void	destinerror(void);
+bool	diffcolor(const struct cardtype *, const struct cardtype *);
+void	dumberror(void);
+bool	finish(void);
+void	fndbase(struct cardtype **, int, int);
+void	getcmd(int, int, const char *);
+void	initall(void);
+void	initdeck(struct cardtype *[]);
+void	initgame(void);
+void	instruct(void);
+int	main(void);
+void	makeboard(void);
+void	movebox(void);
+void	movecard(void);
+void	movetofound(struct cardtype **, int);
+void	movetotalon(void);
+bool	notempty(const struct cardtype *);
+void	printbottombettingbox(void);
+void	printbottominstructions(void);
+void	printcard(int, int, const struct cardtype *);
+void	printrank(int, int, const struct cardtype *, bool);
+void	printtopbettingbox(void);
+void	printtopinstructions(void);
+bool	rankhigher(const struct cardtype *, int);
+bool	ranklower(const struct cardtype *, const struct cardtype *);
+void	removecard(int, int);
+int	samesuit(const struct cardtype *, int);
+void	showcards(void);
+void	showstat(void);
+void	shuffle(struct cardtype *[]);
+void	simpletableau(struct cardtype **, int);
+void	startgame(void);
+void	suspend(void);
+bool	tabok(const struct cardtype *, int);
+void	tabprint(int, int);
+void	tabtotab(int, int);
+void	transit(struct cardtype **, struct cardtype **);
+void	updatebettinginfo(void);
+void	usedstock(void);
+void	usedtalon(void);
 
 /*
  * The following procedures print the board onto the screen using the
@@ -1167,24 +1163,25 @@ updatebettinginfo()
 	if (status != BETTINGBOX)
 		return;
 	move(tboxrow + 2, boxcol + 13);
-	printw("%4d%8d%9d", this.hand, game.hand, total.hand);
+	printw("%4ld%8ld%9ld", this.hand, game.hand, total.hand);
 	move(tboxrow + 3, boxcol + 13);
-	printw("%4d%8d%9d", this.inspection, game.inspection, total.inspection);
+	printw("%4ld%8ld%9ld", this.inspection, game.inspection,
+	    total.inspection);
 	move(tboxrow + 4, boxcol + 13);
-	printw("%4d%8d%9d", this.game, game.game, total.game);
+	printw("%4ld%8ld%9ld", this.game, game.game, total.game);
 	move(tboxrow + 5, boxcol + 13);
-	printw("%4d%8d%9d", this.runs, game.runs, total.runs);
+	printw("%4ld%8ld%9ld", this.runs, game.runs, total.runs);
 	move(tboxrow + 6, boxcol + 13);
-	printw("%4d%8d%9d", this.information, game.information,
+	printw("%4ld%8ld%9ld", this.information, game.information,
 		total.information);
 	move(tboxrow + 7, boxcol + 13);
-	printw("%4d%8d%9d", this.thinktime, game.thinktime, total.thinktime);
+	printw("%4ld%8ld%9ld", this.thinktime, game.thinktime, total.thinktime);
 	move(tboxrow + 8, boxcol + 13);
-	printw("%4d%8d%9d", thiscosts, gamecosts, totalcosts);
+	printw("%4ld%8ld%9ld", thiscosts, gamecosts, totalcosts);
 	move(tboxrow + 9, boxcol + 13);
-	printw("%4d%8d%9d", this.wins, game.wins, total.wins);
+	printw("%4ld%8ld%9ld", this.wins, game.wins, total.wins);
 	move(tboxrow + 10, boxcol + 13);
-	printw("%4d%8d%9d", this.worth, game.worth, total.worth);
+	printw("%4ld%8ld%9ld", this.worth, game.worth, total.worth);
 	move(tboxrow + 11, boxcol + 13);
 	printw("%4.0f%%%7.1f%%%8.1f%%", thisreturn, gamereturn, totalreturn);
 }
