@@ -1,4 +1,4 @@
-/*	$NetBSD: instr.c,v 1.7 1997/10/11 02:44:31 lukem Exp $	*/
+/*	$NetBSD: instr.c,v 1.10 2003/08/07 09:37:10 agc Exp $	*/
 
 /*-
  * Copyright (c) 1990, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)instr.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: instr.c,v 1.7 1997/10/11 02:44:31 lukem Exp $");
+__RCSID("$NetBSD: instr.c,v 1.10 2003/08/07 09:37:10 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -90,7 +86,7 @@ instructions()
 			_exit(1);
 		}
 		execl("/bin/sh", "sh", "-c", path, NULL);
-		warn("%s", "");
+		warn(NULL);
 		_exit(1);
 	default:
 		do {
