@@ -1,4 +1,4 @@
-/*	$NetBSD: dm.c,v 1.11 1998/09/13 15:27:27 hubertf Exp $	*/
+/*	$NetBSD: dm.c,v 1.20 2004/02/08 22:23:50 jsm Exp $	*/
 
 /*
  * Copyright (c) 1987, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1987, 1993\n\
 #if 0
 static char sccsid[] = "@(#)dm.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: dm.c,v 1.11 1998/09/13 15:27:27 hubertf Exp $");
+__RCSID("$NetBSD: dm.c,v 1.20 2004/02/08 22:23:50 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -61,8 +57,8 @@ __RCSID("$NetBSD: dm.c,v 1.11 1998/09/13 15:27:27 hubertf Exp $");
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
-#include <utmp.h>
 
+#include "utmpentry.h"
 #include "pathnames.h"
 
 static time_t	now;			/* current time value */
@@ -70,16 +66,16 @@ static int	priority = 0;		/* priority game runs at */
 static char	*game,			/* requested game */
 		*gametty;		/* from tty? */
 
-void	c_day __P((const char *, const char *, const char *));
-void	c_game __P((const char *, const char  *, const char *, const char *));
-void	c_tty __P((const char *));
-const char *hour __P((int));
-double	load __P((void));
-int	main __P((int, char *[]));
-void	nogamefile __P((void));
-void	play __P((char **)) __attribute__((__noreturn__));
-void	read_config __P((void));
-int	users __P((void));
+void	c_day(const char *, const char *, const char *);
+void	c_game(const char *, const char  *, const char *, const char *);
+void	c_tty(const char *);
+const char *hour(int);
+double	load(void);
+int	main(int, char *[]);
+void	nogamefile(void);
+void	play(char **) __attribute__((__noreturn__));
+void	read_config(void);
+int	users(void);
 
 int
 main(argc, argv)
@@ -116,10 +112,7 @@ play(args)
 {
 	char pbuf[MAXPATHLEN];
 
-	(void)strncpy(pbuf, _PATH_HIDE, sizeof(pbuf) - 1);
-	(void)strncpy(pbuf + sizeof(_PATH_HIDE) - 1, game,
-	    sizeof(pbuf) - sizeof(_PATH_HIDE) - 1);
-	pbuf[sizeof(pbuf) - 1] = '\0';
+	snprintf(pbuf, sizeof(pbuf), "%s%s", _PATH_HIDE, game);
 	if (priority > 0)	/* < 0 requires root */
 		(void)setpriority(PRIO_PROCESS, 0, priority);
 	execv(pbuf, args);
@@ -259,16 +252,16 @@ load()
 int
 users()
 {
-	
-	int nusers, utmp;
-	struct utmp buf;
+	static struct utmpentry *ohead = NULL;	
+	struct utmpentry *ep;
+	int nusers;
 
-	if ((utmp = open(_PATH_UTMP, O_RDONLY, 0)) < 0)
-		err(1, "%s", _PATH_UTMP);
-	for (nusers = 0; read(utmp, (char *)&buf, sizeof(struct utmp)) > 0;)
-		if (buf.ut_name[0] != '\0')
-			++nusers;
-	return (nusers);
+	nusers = getutentries(NULL, &ep);
+	if (ep != ohead) {
+		freeutentries(ep);
+		ohead = ep;
+	}
+	return nusers;
 }
 
 void
