@@ -1,4 +1,4 @@
-/*	$NetBSD: getinp.c,v 1.8 1999/09/08 21:17:51 jsm Exp $	*/
+/*	$NetBSD: getinp.c,v 1.12 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -38,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)getinp.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: getinp.c,v 1.8 1999/09/08 21:17:51 jsm Exp $");
+__RCSID("$NetBSD: getinp.c,v 1.12 2004/01/27 20:30:30 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -51,7 +47,7 @@ __RCSID("$NetBSD: getinp.c,v 1.8 1999/09/08 21:17:51 jsm Exp $");
 
 static char	buf[257];
 
-static int comp __P((const char *));
+static int comp(const char *);
 
 int
 getinp(prompt, list)
@@ -63,10 +59,10 @@ getinp(prompt, list)
 
 	for (;;) {
 inter:
-		printf(prompt);
+		printf("%s", prompt);
 		for (sp = buf; (c=getchar()) != '\n'; ) {
 			*sp = c;
-			if (c == -1)	/* check for interupted system call */
+			if (c == -1)	/* check for interrupted system call */
 				goto inter;
 			else if (sp != buf || *sp != ' ')
 				sp++;
@@ -84,7 +80,7 @@ inter:
 					printf("<RETURN>");
 				}
 				else
-					printf(list[i]);
+					printf("%s", list[i]);
 				if (list[i+1])
 					printf(", ");
 				else
