@@ -1,4 +1,4 @@
-/*	$NetBSD: main.c,v 1.5 1998/08/30 09:19:39 veego Exp $	*/
+/*	$NetBSD: main.c,v 1.12 2004/01/01 16:03:46 jsm Exp $	*/
 
 /*
  * Phantasia 3.3.2 -- Interterminal fantasy game
@@ -58,7 +58,7 @@
 
 #include "include.h"
 
-int	main __P((int, char **));
+int	main(int, char **);
 
 int
 main(argc, argv)
@@ -386,7 +386,7 @@ rollnewplayer()
 	do {
 		mvaddstr(20, 0, "Give your character a password [up to 8 characters] ? ");
 		getstring(Player.p_password, SZ_PASSWORD);
-		mvaddstr(21, 0, "One more time to verify ? ");
+		mvaddstr(21, 0, "Enter again to verify: ");
 		getstring(Databuf, SZ_PASSWORD);
 	}
 	while (strcmp(Player.p_password, Databuf) != 0);
@@ -985,7 +985,7 @@ playinit()
 
 	initscr();		/* turn on curses */
 	noecho();		/* do not echo input */
-	crmode();		/* do not process erase, kill */
+	cbreak();		/* do not process erase, kill */
 #ifdef NCURSES_VERSION /* Ncurses needs some terminal mode fiddling */
 	tcgetattr(0, &tty);
 	tty.c_iflag |= ICRNL;
@@ -1003,13 +1003,17 @@ cleanup(doexit)
 	if (Windows) {
 		move(LINES - 2, 0);
 		refresh();
-		nocrmode();
+		nocbreak();
 		endwin();
 	}
-	fclose(Playersfp);
-	fclose(Monstfp);
-	fclose(Messagefp);
-	fclose(Energyvoidfp);
+	if (Playersfp)
+		fclose(Playersfp);
+	if (Monstfp)
+		fclose(Monstfp);
+	if (Messagefp)
+		fclose(Messagefp);
+	if (Energyvoidfp)
+		fclose(Energyvoidfp);
 
 	if (doexit)
 		exit(0);
