@@ -1,4 +1,4 @@
-/*	$NetBSD: setup.c,v 1.10 1999/09/19 18:14:52 jsm Exp $	*/
+/*	$NetBSD: setup.c,v 1.12 2003/05/08 13:03:49 wiz Exp $	*/
 
 /*
  * setup.c - set up all files for Phantasia
@@ -8,9 +8,9 @@
 #include <fcntl.h>
 #include "include.h"
 
-int main __P((int, char *[]));
-void Error __P((const char *, const char *)) __attribute__((__noreturn__));
-double drandom __P((void));
+int main(int, char *[]);
+void Error(const char *, const char *) __attribute__((__noreturn__));
+double drandom(void);
 
 /**/
 /************************************************************************
@@ -63,12 +63,12 @@ main(argc, argv)
 	int argc;
 	char *argv[];
 {
-	register const char *const *filename; /* for pointing to file names */
-	register int	fd;		/* file descriptor */
-	FILE	*fp;			/* for opening files */
+	const char *const *filename; /* for pointing to file names */
+	int		fd;		/* file descriptor */
+	FILE		*fp;			/* for opening files */
 	struct stat	fbuf;		/* for getting files statistics */
 	int ch;
-	char path[MAXPATHLEN], *prefix;
+	char *path;
 
 	while ((ch = getopt(argc, argv, "m:")) != -1)
 		switch(ch) {
@@ -86,31 +86,15 @@ main(argc, argv)
 
     umask(0117);		/* only owner can read/write created files */
 
-    prefix = getenv("DESTDIR");
-
     /* try to create data files */
     filename = &files[0];
     while (*filename != NULL)
 	/* create each file */
 	{
-	snprintf(path, sizeof(path), "%s%s", prefix?prefix:"", *filename);
+	path = strrchr(*filename, '/') + 1;
 	if (stat(path, &fbuf) == 0)
 	    /* file exists; remove it */
 	    {
-	    if (!strcmp(*filename, _PATH_PEOPLE))
-		/* do not reset character file if it already exists */
-		{
-		++filename;
-		continue;
-		}
-
-	    if (!strcmp(*filename, _PATH_SCORE))
-		/* do not reset score file if it already exists */
-		{
-		++filename;
-		continue;
-		}
-
 	    if (unlink(path) < 0)
 		Error("Cannot unlink %s.\n", path);
 		/*NOTREACHED*/
@@ -129,7 +113,7 @@ main(argc, argv)
     Enrgyvoid.ev_active = TRUE;
     Enrgyvoid.ev_x = ROLL(-1.0e6, 2.0e6);
     Enrgyvoid.ev_y = ROLL(-1.0e6, 2.0e6);
-    snprintf(path, sizeof(path), "%s%s", prefix?prefix:"", _PATH_VOID);
+    path = strrchr(_PATH_VOID, '/') + 1;
     if ((fp = fopen(path, "w")) == NULL)
 	Error("Cannot update %s.\n", path);
     else
@@ -142,7 +126,7 @@ main(argc, argv)
 	}
 
     /* create binary monster data base */
-    snprintf(path, sizeof(path), "%s%s", prefix?prefix:"", _PATH_MONST);
+    path = strrchr(_PATH_MONST, '/') + 1;
     if ((Monstfp = fopen(path, "w")) == NULL)
 	Error("Cannot update %s.\n", path);
     else
@@ -186,7 +170,7 @@ main(argc, argv)
     printf("One line 'motd' ? ");
     if (fgets(Databuf, SZ_DATABUF, stdin) == NULL)
 	Databuf[0] = '\0';
-    snprintf(path, sizeof(path), "%s%s", prefix?prefix:"", _PATH_MOTD);
+    path = strrchr(_PATH_MOTD, '/') + 1;
     if ((fp = fopen(path, "w")) == NULL)
 	Error("Cannot update %s.\n", path);
     else
