@@ -1,4 +1,4 @@
-/*	$NetBSD: pig.c,v 1.7 1998/09/13 15:27:29 hubertf Exp $	*/
+/*	$NetBSD: pig.c,v 1.10 2004/01/27 20:30:30 jsm Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1992, 1993\n\
 #if 0
 static char sccsid[] = "@(#)pig.c	8.2 (Berkeley) 5/4/95";
 #else
-__RCSID("$NetBSD: pig.c,v 1.7 1998/09/13 15:27:29 hubertf Exp $");
+__RCSID("$NetBSD: pig.c,v 1.10 2004/01/27 20:30:30 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -56,9 +52,9 @@ __RCSID("$NetBSD: pig.c,v 1.7 1998/09/13 15:27:29 hubertf Exp $");
 #include <string.h>
 #include <unistd.h>
 
-int main __P((int, char *[]));
-void pigout __P((char *, int));
-void usage __P((void)) __attribute__((__noreturn__));
+int main(int, char *[]);
+void pigout(char *, int);
+void usage(void) __attribute__((__noreturn__));
 
 int
 main(argc, argv)
