@@ -1,4 +1,4 @@
-/*	$NetBSD: rain.c,v 1.13 1999/08/08 02:06:01 simonb Exp $	*/
+/*	$NetBSD: rain.c,v 1.16 2004/02/08 22:21:57 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -43,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 1993\n\
 #if 0
 static char sccsid[] = "@(#)rain.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: rain.c,v 1.13 1999/08/08 02:06:01 simonb Exp $");
+__RCSID("$NetBSD: rain.c,v 1.16 2004/02/08 22:21:57 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -58,12 +54,13 @@ __RCSID("$NetBSD: rain.c,v 1.13 1999/08/08 02:06:01 simonb Exp $");
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <termios.h>
 #include <unistd.h>
 
 volatile sig_atomic_t sig_caught = 0;
 
-int	main __P((int, char **));
-void	onsig __P((int));
+int	main(int, char **);
+void	onsig(int);
 
 
 int
@@ -95,7 +92,6 @@ main(argc, argv)
 		}
 
 	initscr();
-	leaveok(stdscr, TRUE);
 	cols = COLS - 4;
 	lines = LINES - 4;
 
@@ -106,6 +102,7 @@ main(argc, argv)
 	(void)signal(SIGTSTP, onsig);
 	(void)signal(SIGTERM, onsig);
 
+	curs_set(0);
 	for (j = 4; j >= 0; --j) {
 		xpos[j] = random() % cols + 2;
 		ypos[j] = random() % lines + 2;
@@ -144,7 +141,10 @@ main(argc, argv)
 		xpos[j] = x;
 		ypos[j] = y;
 		refresh();
-		if (delay) usleep(delay);
+		if (delay)
+			usleep(delay);
+		else
+			tcdrain(STDOUT_FILENO);
 	}
 }
 
