@@ -1,4 +1,4 @@
-/*	$NetBSD: trek.h,v 1.5 1997/10/12 21:25:23 christos Exp $	*/
+/*	$NetBSD: trek.h,v 1.10 2004/01/27 20:30:31 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -12,11 +12,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -45,12 +41,6 @@
 **
 **	So far as I know, nothing in here must be preinitialized to
 **	zero.
-**
-**	You may have problems from the loader if you move this to a
-**	different machine.  These things actually get allocated in each
-**	source file, which UNIX allows; however, you may (on other
-**	systems) have to change everything in here to be "extern" and
-**	actually allocate stuff in "externs.c"
 */
 
 /* external function definitions */
@@ -93,7 +83,7 @@ struct quad		/* definition for each quadrant */
 extern const char	*const Systemname[NINHAB];
 
 /* quadrant definition */
-struct quad	Quad[NQUADS][NQUADS];
+extern struct quad	Quad[NQUADS][NQUADS];
 
 /* defines for sector map  (below) */
 # define	EMPTY		'.'
@@ -106,7 +96,7 @@ struct quad	Quad[NQUADS][NQUADS];
 # define	HOLE		' '
 
 /* current sector map */
-char	Sect[NSECTS][NSECTS];
+extern char	Sect[NSECTS][NSECTS];
 
 
 
@@ -137,7 +127,7 @@ struct device
 	const char	*person;	/* the person who fixes it */
 };
 
-const struct device	Device[NDEV];
+extern const struct device	Device[NDEV];
 
 /***************************  EVENTS  ****************************/
 
@@ -177,7 +167,7 @@ struct event
 
 # define	MAXEVENTS	25	/* max number of concurrently pending events */
 
-struct event	Event[MAXEVENTS];	/* dynamic event list; one entry per pending event */
+extern struct event	Event[MAXEVENTS];	/* dynamic event list; one entry per pending event */
 
 /*****************************  KLINGONS  *******************************/
 
@@ -225,7 +215,7 @@ extern const struct cvntab	Lentab[];
 
 
 /* information regarding the state of the starship */
-struct
+struct Ship_struct
 {
 	double	warp;		/* warp factor */
 	double	warp2;		/* warp factor squared */
@@ -248,12 +238,13 @@ struct
 	const char *shipname;	/* name of current starship */
 	char	ship;		/* current starship */
 	int	distressed;	/* number of distress calls */
-}	Ship;
+};
+extern struct Ship_struct Ship;
 
 /* sinsbad is set if SINS is working but not calibrated */
 
 /* game related information, mostly scoring */
-struct
+struct Game_struct
 {
 	int	killk;		/* number of klingons killed */
 	int	deaths;		/* number of deaths onboard Enterprise */
@@ -269,10 +260,11 @@ struct
 	char	snap;		/* set if snapshot taken */
 	char	helps;		/* number of help calls */
 	int	captives;	/* total number of captives taken */
-}	Game;
+};
+extern struct Game_struct Game;
 
 /* per move information */
-struct
+struct Move_struct
 {
 	char	free;		/* set if a move is free */
 	char	endgame;	/* end of game flag */
@@ -280,10 +272,11 @@ struct
 	char	newquad;	/* set if just entered this quadrant */
 	char	resting;	/* set if this move is a rest */
 	double	time;		/* time used this move */
-}	Move;
+};
+extern struct Move_struct Move;
 
 /* parametric information */
-struct
+struct Param_struct
 {
 	unsigned char	bases;	/* number of starbases */
 	char	klings;		/* number of klingons */
@@ -314,12 +307,13 @@ struct
 	int	klingcrew;	/* number of Klingons in a crew */
 	double	srndrprob;	/* surrender probability */
 	int	energylow;	/* low energy mark (cond YELLOW) */
-}	Param;
+};
+extern struct Param_struct Param;
 
 /* Sum of damage probabilities must add to 1000 */
 
 /* other information kept in a snapshot */
-struct
+struct Now_struct
 {
 	unsigned char	bases;	/* number of starbases */
 	char	klings;		/* number of klingons */
@@ -329,10 +323,11 @@ struct
 	char	distressed;	/* number of currently distressed quadrants */
 	struct event	*eventptr[NEVENTS];	/* pointer to event structs */
 	struct xy	base[MAXBASES];		/* locations of starbases */
-}	Now;
+};
+extern struct Now_struct Now;
 
 /* Other stuff, not dumped in a snapshot */
-struct
+struct Etc_struct
 {
 	struct kling	klingon[MAXKLQUAD];	/* sorted Klingon list */
 	short		nkling;			/* number of Klingons in this sector */
@@ -341,7 +336,8 @@ struct
 	struct xy	starbase;	/* starbase in current quadrant */
 	char		snapshot[sizeof Quad + sizeof Event + sizeof Now];	/* snapshot for time warp */
 	char		statreport;		/* set to get a status report on a srscan */
-}	Etc;
+};
+extern struct Etc_struct Etc;
 
 /*
  *	eventptr is a pointer to the event[] entry of the last
@@ -375,158 +371,158 @@ struct
 
 /* Trace info */
 # define	xTRACE		1
-int	Trace;
+extern int	Trace;
 
 /* abandon.c */
-void abandon __P((int));
+void abandon(int);
 
 /* attack.c */
-void attack __P((int));
+void attack(int);
 
 /* autover.c */
-void autover __P((void));
+void autover(void);
 
 /* capture.c */
-void capture __P((int));
-struct kling *selectklingon __P((void));
+void capture(int);
+struct kling *selectklingon(void);
 
 /* cgetc.c */
-char cgetc __P((int));
+char cgetc(int);
 
 /* check_out.c */
-int check_out __P((int));
+int check_out(int);
 
 /* checkcond.c */
-void checkcond __P((void));
+void checkcond(void);
 
 /* compkl.c */
-void compkldist __P((int));
+void compkldist(int);
 
 /* computer.c */
-void computer __P((int));
+void computer(int);
 
 /* damage.c */
-void damage __P((int, double));
+void damage(int, double);
 
 /* damaged.c */
-int damaged __P((int));
+int damaged(int);
 
 /* dcrept.c */
-void dcrept __P((int));
+void dcrept(int);
 
 /* destruct.c */
-void destruct __P((int));
+void destruct(int);
 
 /* dock.c */
-void dock __P((int));
-void undock __P((int));
+void dock(int);
+void undock(int);
 
 /* dumpgame.c */
-void dumpgame __P((int));
-int restartgame __P((void));
+void dumpgame(int);
+int restartgame(void);
 
 /* dumpme.c */
-void dumpme __P((int));
+void dumpme(int);
 
 /* dumpssradio.c */
-int dumpssradio __P((void));
+int dumpssradio(void);
 
 /* events.c */
-int events __P((int));
+int events(int);
 
 /* externs.c */
 
 /* getcodi.c */
-int getcodi __P((int *, double *));
+int getcodi(int *, double *);
 
 /* help.c */
-void help __P((int));
+void help(int);
 
 /* impulse.c */
-void impulse __P((int));
+void impulse(int);
 
 /* initquad.c */
-void initquad __P((int));
-void sector __P((int *, int *));
+void initquad(int);
+void sector(int *, int *);
 
 /* kill.c */
-void killk __P((int, int ));
-void killb __P((int, int ));
-void kills __P((int, int , int));
-void killd __P((int, int , int));
+void killk(int, int );
+void killb(int, int );
+void kills(int, int , int);
+void killd(int, int , int);
 
 /* klmove.c */
-void klmove __P((int));
+void klmove(int);
 
 /* lose.c */
-void lose __P((int));
+void lose(int) __attribute__((__noreturn__));
 
 /* lrscan.c */
-void lrscan __P((int));
+void lrscan(int);
 
 /* move.c */
-double move __P((int, int, double, double));
+double move(int, int, double, double);
 
 /* nova.c */
-void nova __P((int, int ));
+void nova(int, int );
 
 /* out.c */
-void out __P((int));
+void out(int);
 
 /* phaser.c */
-void phaser __P((int));
+void phaser(int);
 
 /* play.c */
-void myreset __P((int));
-void play __P((void));
+void myreset(int) __attribute__((__noreturn__));
+void play(void) __attribute__((__noreturn__));
 
 /* ram.c */
-void ram __P((int, int ));
+void ram(int, int );
 
 /* ranf.c */
-int ranf __P((int));
-double franf __P((void));
+int ranf(int);
+double franf(void);
 
 /* rest.c */
-void rest __P((int));
+void rest(int);
 
 /* schedule.c */
-struct event *schedule __P((int, double, int, int , int));
-void reschedule __P((struct event *, double));
-void unschedule __P((struct event *));
-struct event *xsched __P((int, int, int, int , int ));
-void xresched __P((struct event *, int, int));
+struct event *schedule(int, double, int, int , int);
+void reschedule(struct event *, double);
+void unschedule(struct event *);
+struct event *xsched(int, int, int, int , int );
+void xresched(struct event *, int, int);
 
 /* score.c */
-long score __P((void));
+long score(void);
 
 /* setup.c */
-void setup __P((void));
+void setup(void);
 
 /* setwarp.c */
-void setwarp __P((int));
+void setwarp(int);
 
 /* shield.c */
-void shield __P((int));
+void shield(int);
 
 /* snova.c */
-void snova __P((int, int ));
+void snova(int, int );
 
 /* srscan.c */
-void srscan __P((int));
+void srscan(int);
 
 /* systemname.c */
-const char *systemname __P((const struct quad *));
+const char *systemname(const struct quad *);
 
 /* torped.c */
-void torped __P((int));
+void torped(int);
 
 /* visual.c */
-void visual __P((int));
+void visual(int);
 
 /* warp.c */
-void dowarp __P((int));
-void warp __P((int, int, double));
+void dowarp(int);
+void warp(int, int, double);
 
 /* win.c */
-void win __P((void));
+void win(void) __attribute__((__noreturn__));
