@@ -1,4 +1,4 @@
-/*	$NetBSD: wump.c,v 1.8 1999/02/10 01:44:34 hubertf Exp $	*/
+/*	$NetBSD: wump.c,v 1.16 2004/01/27 20:30:31 jsm Exp $	*/
 
 /*
  * Copyright (c) 1989, 1993
@@ -16,11 +16,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -47,7 +43,7 @@ __COPYRIGHT("@(#) Copyright (c) 1989, 1993\n\
 #if 0
 static char sccsid[] = "@(#)wump.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: wump.c,v 1.8 1999/02/10 01:44:34 hubertf Exp $");
+__RCSID("$NetBSD: wump.c,v 1.16 2004/01/27 20:30:31 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -116,29 +112,30 @@ int arrow_num = NUMBER_OF_ARROWS;	/* arrow inventory */
 
 char answer[20];			/* user input */
 
-int	bats_nearby __P((void));
-void	cave_init __P((void));
-void	clear_things_in_cave __P((void));
-void	display_room_stats __P((void));
-int	getans __P((const char *));
-void	initialize_things_in_cave __P((void));
-void	instructions __P((void));
-int	int_compare __P((const void *, const void *));
-void	jump __P((int));
-void	kill_wump __P((void));
-int	main __P((int, char **));
-int	move_to __P((const char *));
-void	move_wump __P((void));
-void	no_arrows __P((void));
-void	pit_kill __P((void));
-int	pit_nearby __P((void));
-void	pit_survive __P((void));
-int	shoot __P((char *));
-void	shoot_self __P((void));
-int	take_action __P((void));
-void	usage __P((void)) __attribute__((__noreturn__));
-void	wump_kill __P((void));
-int	wump_nearby __P((void));
+int	bats_nearby(void);
+void	cave_init(void);
+void	clear_things_in_cave(void);
+void	display_room_stats(void);
+int	gcd(int, int);
+int	getans(const char *);
+void	initialize_things_in_cave(void);
+void	instructions(void);
+int	int_compare(const void *, const void *);
+void	jump(int);
+void	kill_wump(void);
+int	main(int, char **);
+int	move_to(const char *);
+void	move_wump(void);
+void	no_arrows(void);
+void	pit_kill(void);
+int	pit_nearby(void);
+void	pit_survive(void);
+int	shoot(char *);
+void	shoot_self(void);
+int	take_action(void);
+void	usage(void) __attribute__((__noreturn__));
+void	wump_kill(void);
+int	wump_nearby(void);
 
 int
 main(argc, argv)
@@ -520,6 +517,18 @@ The arrow is weakly shot and can go no further!\n");
 	return(0);
 }
 
+int
+gcd(a, b)
+	int a, b;
+{
+	int r;
+
+	r = a % b;
+	if (r == 0)
+		return (b);
+	return (gcd(b, r));
+}
+
 void
 cave_init()
 {
@@ -542,8 +551,14 @@ cave_init()
 		for (j = 0; j < link_num ; ++j)
 			cave[i].tunnel[j] = -1;
 
-	/* choose a random 'hop' delta for our guaranteed link */
-	while (!(delta = random() % room_num));
+	/*
+	 * Choose a random 'hop' delta for our guaranteed link.
+	 * To keep the cave connected, we need the greatest common divisor
+	 * of (delta + 1) and room_num to be 1.
+	 */
+	do {
+		delta = (random() % (room_num - 1)) + 1;
+	} while (gcd(room_num, delta + 1) != 1);
 
 	for (i = 1; i <= room_num; ++i) {
 		link = ((i + delta) % room_num) + 1;	/* connection */
@@ -749,7 +764,7 @@ puff of greasy black smoke! (poof)\n");
 		return;
 	}
 
-	if (!isatty(1))
+	if (!isatty(STDOUT_FILENO))
 		pager = "cat";
 	else {
 		if (!(pager = getenv("PAGER")) || (*pager == 0))
@@ -759,7 +774,7 @@ puff of greasy black smoke! (poof)\n");
 	case 0: /* child */
 		if ((fd = open(_PATH_WUMPINFO, O_RDONLY)) == -1)
 			err(1, "open %s", _PATH_WUMPINFO);
-		if (dup2(fd, 0) == -1)
+		if (dup2(fd, STDIN_FILENO) == -1)
 			err(1, "dup2");
 		(void)execl("/bin/sh", "sh", "-c", pager, NULL);
 		err(1, "exec sh -c %s", pager);
